.. image:: tinamit/Interfaz/Imágenes/LogoCent.png
   :scale: 80%
   :alt: Logo muy bonito
   
Tinamit
=======
Programa para conectar modelos socioeconómicos (dinámicas de los sistemas) con modelos biofísicos.

Tinamit permite la conexión rápida, flexible y reproducible de modelos con:

* Un interfaz (IGU) para los que no quieren escribir código.
* Un libreria (IPA) para las que sí.
* Una estructura fácil para conectar modelos en menos de 10 líneas (en vez de cientos).
* Una estructura transparente para que todos puedan agregar modelos y recursos.
* Apoyo multilingual en el IGU.

Autores
=======

* Julien Malard julien.malard@mail.mcgill.ca
* محمّد اظہر انعام بیگ  muhammad.baig@mail.mcgill.ca
